Tutorial
========

Some `scikit-hubness` tutorials.


Installation
------------

Please make sure you have the latest version of `scikit-hubness` installed.
Installation instructions can be found here_.

.. _here: installation.html


Tutorial 1
----------

TODO


Tutorial 2
----------

TODO
